lua_isnumber

Function lua_isnumber 

pub fn lua_isnumber(l: LuaState, idx: c_int) -> c_int
Returns 1 if the value at the given acceptable index is a number or a string convertible to a number, and 0 otherwise.