Function luaJIT_setmode
Source pub fn luaJIT_setmode(l: LuaState, idx: c_int, jit_mode: c_int) -> c_int
This is a C API extension to allow control of the VM from “C”
Parameters
l - Lua state
idx - Stack index of the function to set the mode of. 0 to set the mode of the entirety of luajit.
mode - The mode to set, ’or’ed with a flag from lua::jit
Returns
1 for success, 0 for failure.