pub fn luaL_typerror(l: LuaState, narg: c_int, typename: LuaString) -> !Expand description
Generates an error with a message like the following:
location: bad argument narg to 'func' (tname expected, got rt)where location is produced by luaL_where, func is the name of the current function, and rt is the type name of the actual argument.